load('TriSpec.Scope');
load('White3000KSpec.Scope');
load('DarkSpec.Scope');
load('BlueSpec.Scope');
load('GreenSpec.Scope');
load('RedSpec.Scope');
load('WhiteLEDSpec.Scope');

lambda=TriSpec(:,1);    %wavelength
white=White3000KSpec(:,2);   %3000 Kelvin white spectrum
dark=DarkSpec(:,2);     %dark spectrum
factor=4.598*10^6;      %proportionality constant
std3000=bbspec(3000,lambda/1000)/factor;    %standard 3000 Kelvin curve
cal=std3000./(white-dark);  %calibration curve


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%analyzes the three LEDs shining simultaneously
Tri=TriSpec(:,2);   %raw tri LED data
Trical=cal.*Tri;    %calibrated LED data
%calculates the CIE 1931 coordinates based on the simultaneous LED analysis
[Xtri,Ytri,Ztri]=xyzspec(lambda,Trical);
xtri=Xtri/(Xtri+Ytri+Ztri)
ytri=Ytri/(Xtri+Ytri+Ztri)

%plots calibrated data for simultaneous LEDs
figure;plot(lambda,Trical,'m');
axis([400 800 0 2]);
xlabel('Wavelength (nm)');ylabel('Intensity');
title('Tri LED Simultaneous Analysis');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%analyzes the blue LED individually
blue=BlueSpec(:,2); %raw blue LED data
bluecal=cal.*blue;  %calibrated blue LED data
%calculates the CIE 1931 coordinates based on the blue LED analysis
[Xblue,Yblue,Zblue]=xyzspec(lambda,bluecal);
xblue=Xblue/(Xblue+Yblue+Zblue);
yblue=Yblue/(Xblue+Yblue+Zblue);

%analyzes the green LED individually
green=GreenSpec(:,2);   %raw green LED data
greencal=cal.*green;    %calibrated green LED data
%calculates the CIE 1931 coordinates based on the green LED analysis
[Xgreen,Ygreen,Zgreen]=xyzspec(lambda,greencal);
xgreen=Xgreen/(Xgreen+Ygreen+Zgreen);
ygreen=Ygreen/(Xgreen+Ygreen+Zgreen);

%analyzes the red LED individually
red=RedSpec(:,2);   %raw red LED data
redcal=cal.*red;    %calibrated red LED data
%calculates the CIE 1931 coordinates based on the red LED analysis
[Xred,Yred,Zred]=xyzspec(lambda,redcal);
xred=Xred/(Xred+Yred+Zred);
yred=Yred/(Xred+Yred+Zred);

%calculates the CIE 1931 coordinates based on the average of the 
%blue-green-red individual LED analyses
xcenter=(xblue+xgreen+xred)/3
ycenter=(yblue+ygreen+yred)/3

%plots calibrated data for blue-green-red individual LEDs
figure;plot(lambda,bluecal,'b',lambda,greencal,'g',lambda,redcal,'r');
axis([400 800 0 2]);
xlabel('Wavelength (nm)');ylabel('Intensity');
title('Blue-Green-Red Individual LED Analysis');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%analyzes the "white" LED
whiteLED=WhiteLEDSpec(:,2);   %raw "white" LED data
whiteLEDcal=cal.*whiteLED;    %calibrated LED data
%calculates the CIE 1931 coordinates based on the "white" LED analysis
[Xwhite,Ywhite,Zwhite]=xyzspec(lambda,whiteLEDcal);
xwhite=Xwhite/(Xwhite+Ywhite+Zwhite)
ywhite=Ywhite/(Xwhite+Ywhite+Zwhite)

%plots calibrated data for "white" LED
figure;plot(lambda,whiteLEDcal,'k');
axis([400 800 0 2]);
xlabel('Wavelength (nm)');ylabel('Intensity');
title('"White" LED Analysis');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
