function bookfont(nfont)
% Setup fonts and thickness of lines so when we print it shows up
%
% Usage:
%       bookfont(nfont)
% 
%   where, nfont=1 for figures that will be about 5 inches wide
%       nfont = 2 for figures that will be about 2.5 inches wide.  
%
%    The latter are normally figures that will be combined to make a single figure.
%

xaxisfont=[18,32];
xtextfont=[14,24];
xmarkersize=[10,15];
xlinesize=[3,5];
axisfont=xaxisfont(nfont);
textfont=xtextfont(nfont);
markersize=xmarkersize(nfont);
linesize=xlinesize(nfont);

%% Set default fonts
set(0,'DefaultAxesFontName','Times');
set(0,'DefaultAxesFontSize',axisfont)
set(0,'DefaultAxesFontAngle','normal')
set(0,'DefaultAxesFontWeight','bold')
%
set(0,'DefaultTextFontName','Times');
set(0,'DefaultTextFontSize',textfont)
set(0,'DefaultTextFontAngle','normal')
set(0,'DefaultTextFontWeight','normal')
%  To Change just the properties of a single
%    item remove the words Default<Item> and 
%    use a <handle> to the item:
%
%    set(<handle>,'Property','Setting');
%
%   Example:
%           h=get(gca,'Title');
%           set(h,'FontName','Zapf Dingbats');
%

%% Make markers and lines thicker for printing.
set(0,'DefaultLineMarkerSize',markersize);
set(0,'DefaultLineLineWidth',linesize);

%% Set the colors and line styles
% For most figures in the book we need black and white
%
set(0,'DefaultAxesLineStyleOrder','-|--|-.|:');
set(0,'DefaultAxesColorOrder',[0 0 0]);
