function genbookchapterHTML(fName, outputDir)
%GENBOOKFUNCHELP Generates the HTML Help for a given function
%
% Usage:
%       genbookhelp(functionName,[outputDir])
%
%   where, 
%       functionName is a string containing the function name to generate
%       the HTML help for
%   
%       [outputDir] is an option output directory of where to place the help file
%       by default it will be placed in a Help directory located above the
%       directory of this file.
%
%

%% TODO  If the user sends us a directory we should cycle through all the
%% files in that directory.  Not implemented yet.

%% Create option structure for publishing functions
opts.format = 'html';  %'html' | 'doc' | 'ppt' | 'xml' | 'latex'
opts.stylesheet = '';   %'' | an XSL filename (ignored when format = 'doc' or 'ppt')
opts.imageFormat= 'jpeg'; % '' (default based on format)  | any supported by PRINT or IMWRITE, depending on figureSnapMethod
opts.figureSnapMethod = 'print'; %: 'entireGUIWindow'| 'print' | 'getframe' | 'entireFigureWindow'
opts.useNewFigure = false; %: true | false
opts.maxHeight = []; % [] (unrestricted) | positive integer (pixels) Not used in eps or vector files
opts.maxWidth = []; % [] (unrestricted) | positive integer (pixels) Not used in eps or vector files
opts.showCode = true; % true | false
opts.evalCode = true; % true | false
opts.catchError = false; % true | false
opts.createThumbnail = true; % true | false
opts.maxOutputLines = Inf; % Inf | non-negative integer

if ~exist('outputDir','var')
    x=bookpathinfo();
    path2file = regexprep(which(fName),[fName,'.m'],'');
    regSource = regexprep(x.source,'\\','\\\\');
    regPublish = regexprep(x.publish,'\\','\\\\');
    path2file = regexprep(path2file,regSource,regPublish);
    opts.outputDir = path2file;
else
    opts.outputDir = outputDir;
end

%% Set default fonts
axesFontName = get(0,'DefaultAxesFontName');
axesFontSize = get(0,'DefaultAxesFontSize');
axesFontAngle = get(0,'DefaultAxesFontAngle');
axesFontWeitght = get(0,'DefaultAxesFontWeight');
%
textFontName = get(0,'DefaultTextFontName');
textFontSize = get(0,'DefaultTextFontSize');
textFontAngle = get(0,'DefaultTextFontAngle');
textFontWeight = get(0,'DefaultTextFontWeight');

lineMarkerSize = get(0,'DefaultLineMarkerSize');
lineWidth = get(0,'DefaultLineLineWidth');

%% Make markers and lines thicker for printing.
set(0,'DefaultLineMarkerSize',10);
set(0,'DefaultLineLineWidth',3);

set(0,'DefaultAxesFontName','Times');
set(0,'DefaultAxesFontSize',12)
set(0,'DefaultAxesFontAngle','normal')
set(0,'DefaultAxesFontWeight','bold')
%
set(0,'DefaultTextFontName','Times');
set(0,'DefaultTextFontSize',12)
set(0,'DefaultTextFontAngle','normal')
set(0,'DefaultTextFontWeight','normal')

%% Make markers and lines thicker for printing.
set(0,'DefaultLineMarkerSize',5);
set(0,'DefaultLineLineWidth',2);

%%
pos = get(0,'DefaultFigurePosition');
set(0,'DefaultFigurePosition',[0,0,pos(3)+pos(1),pos(4)+pos(2)]);

%% Set the colors and line styles
% For most figures in the book we need black and white
%
set(0,'DefaultAxesLineStyleOrder','-');
colororder = [      0,         0,    1.0000;
                    0,    0.5000,         0;
               1.0000,         0,         0;
                    0,    0.7500,    0.7500;
               0.7500,         0,    0.7500;
               0.7500,    0.7500,         0;
               0.2500,    0.2500,    0.2500];
set(0,'DefaultAxesColorOrder',colororder);


%% Publish the file
createdFile = publish(fName,opts);

%% Undo Changing of Defaults
set(0,'DefaultFigurePosition',pos);
set(0,'DefaultAxesFontName',axesFontName);
set(0,'DefaultAxesFontSize',axesFontSize);
set(0,'DefaultAxesFontAngle',axesFontAngle);
set(0,'DefaultAxesFontWeight',axesFontWeitght);
%
set(0,'DefaultTextFontName',textFontName);
set(0,'DefaultTextFontSize',textFontSize);
set(0,'DefaultTextFontAngle',textFontAngle);
set(0,'DefaultTextFontWeight',textFontWeight);

set(0,'DefaultLineMarkerSize',lineMarkerSize);
set(0,'DefaultLineLineWidth',lineWidth);


%% View created file
open(createdFile);
end