function genbookfunchelp(fName, outputDir)
%GENBOOKFUNCHELP Generates the HTML Help for a given function
%
% Usage:
%       genbookhelp(functionName,[outputDir])
%
%   where, 
%       functionName is a string containing the function name to generate
%       the HTML help for
%   
%       [outputDir] is an option output directory of where to place the help file
%       by default it will be placed in a mirrored directory under the path
%       specified in publish
%
% See Also:  bookpathinfo

%% TODO  If the user sends us a directory we should cycle through all the
%% files in that directory.  Not implemented yet.

%% Create option structure for publishing functions
opts.format = 'html';  %'html' | 'doc' | 'ppt' | 'xml' | 'latex'
opts.stylesheet = '';   %'' | an XSL filename (ignored when format = 'doc' or 'ppt')
opts.imageFormat= ''; % '' (default based on format)  | any supported by PRINT or IMWRITE, depending on figureSnapMethod
opts.figureSnapMethod = 'print'; %: 'entireGUIWindow'| 'print' | 'getframe' | 'entireFigureWindow'
opts.useNewFigure = false; %: true | false
opts.maxHeight = []; % [] (unrestricted) | positive integer (pixels) Not used in eps or vector files
opts.maxWidth = []; % [] (unrestricted) | positive integer (pixels) Not used in eps or vector files
opts.showCode = true; % true | false
opts.evalCode = false; % true | false
opts.catchError = false; % true | false
opts.createThumbnail = true; % true | false
opts.maxOutputLines = Inf; % Inf | non-negative integer

if ~exist('outputDir','var')
    x=bookpathinfo();
    path2file = regexprep(which(fName),[fName,'.m'],'');
    regSource = regexprep(x.source,'\\','\\\\');
    regPublish = regexprep(x.publish,'\\','\\\\');
    path2file = regexprep(path2file,regSource,regPublish);
    opts.outputDir = path2file;
else
    opts.outputDir = outputDir;
end

%% Publish the file
createdFile = publish(fName,opts);

%% View created file
open(createdFile);
end