%% OCT  Plots a synthetic OCT image
%
% SYNTAX;
%  oct;
%
% by Chuck DiMarzio
%    Northeastern University
%    August 2009
%
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
%% Set up parameters
lambda=830e-9;  % Wavelength, m
cl=5*lambda;   % Coherence length
dz=(-5:0.1:11)*lambda;  % difference in paths in Michaelson interferometer
e1mag=1;e2mag=0.1; % Field magnitudes at detector

%% Compute and plot OCT signal for one target
gamma=exp(-(dz/(cl/2)).^2);    % autocorrelation function
signal=e1mag^2+e2mag^2+2*e1mag*e2mag*gamma.*cos(2*pi*2*dz/lambda);
fig1=figure;
plot(dz*1e6,signal);grid on;
xlabel('dz, Path Difference, \mu m');
ylabel('Signal');

%% Now do a second target
e2mag=0.05;
loc2=8*lambda; % Location of second target
gamma=exp(-((dz-loc2)/(cl/2)).^2);    % autocorrelation function
signal=signal+...
  e1mag^2+e2mag^2+2*e1mag*e2mag*gamma.*cos(2*pi*2*(dz-loc2)/lambda);
fig2=figure;
plot(dz*1e6,signal);grid on;
xlabel('dz, Path Difference, \mu m');
ylabel('Signal');
