%% SPECKLE computes size of speckle pattern
%
% SYNTAX;
%  speckle;
%
% by Chuck DiMarzio
%    Northeastern University
%    August 2009
%
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
% Light from a laser is focused to a spot on a ground glass.
% We want to know the size of the speckles on a screen some 
%   distance away. 
%
%% Set parameters
lambda=532e-9; % Doubled Nd:YAG
d0=2.7e-6/2;     % Waist diameter with NA=0.25
b=pi*d0^2/4/lambda; % Rayleigh range
z=(-5:0.05:5)*b;    % Vary z through focus
zscreen=0.3;      % Distance to screen
%
%% Compute beam diameter at glass, speckle diameter, and plot
dglass=d0*sqrt(1+(z/b).^2); % beam diameter on the glass
dspeckle=4/pi*lambda./dglass*zscreen;  % speckle diameter on the screen
%
fig1=figure;plot(z*1e6,dspeckle*1e3);grid on;
moose=axis;
axis([moose(1:2),0,moose(4)]);
xlabel('z, Distance from Focus, \mu m');
ylabel('d_{speckle}, mm');
