%% Spatial Filtering
rep=4;box=128;
cb=single(checkerboard(box,rep,rep)>0);  % Generate a checkerboard pattern
cbf=fftshift(fft2(cb));  % Fourier tranform of the pattern. zero-centered
                         % on the frequency axes

xax=fftaxisshift(0:box*rep*2-1);
[x,y]=meshgrid(xax,xax);
rsq=x.^2+y.^2;sombw=24;
somb=0.2+0.5*(1-rsq/sombw^2).*exp(-rsq/sombw^2);  % Laplacian of Gaussian
                                                  % (Sombrero) 
gau=exp(-rsq/sombw^2);  %  Gaussian

fax=fftaxisshift(fftaxis(1:box*rep*2));  % Axis for frequency
[fx,fy]=meshgrid(fax,fax);   % Generate frequency arrays
fsq=fx.^2+fy.^2;  
ftop=max(max(fx)); % Highest frequency displayed
ffundamental=1/box/2;  % Fundamental frequency
fmax=ffundamental*5;fmin=ffundamental*1.;df=ffundamental/2;
%mask2coh=single(((fsq>=((fmin)^2))&(fsq<=((fmax)^2)))); % High Pass
%mask2coh(find(fsq<=fmin^2))=i;

mask1=fftshift(fft2(fftshift(sqrt(gau))));
mask1coh=fftshift(ifft2(abs((fft2(fftshift(mask1)))).^0.5));
cbfmask1=cbf.*mask1; % Multiply input spectrum by filter spectrum
cbimage1=ifft2(fftshift(cbfmask1)); % Ifft to get the image

mask2=fftshift(fft2(fftshift(sqrt(somb))));
mask2coh=fftshift(ifft2(abs((fft2(fftshift(mask2)))).^0.5));
cbfmask2=cbf.*mask2; % Multiply input spectrum by filter spectrum
cbimage2=ifft2(fftshift(cbfmask2)); % Ifft to get the image

fig7=figure;imagesc(real(cb));axis image;colormap(gray);title('Checkerboard');

fig8=figure;imagesc(fax,fax,20*log10(abs(cbf)));axis image;colorbar;
title(['Checkerboard in Pupil']); 
moose=caxis;caxis(moose(2)+[-60,0]);
xlabel('f_x, cycles/pixel');ylabel('f_x, cycles/pixel');

fig10=figure;imagesc(fax,fax,20*log10(abs(mask2coh)));axis image;colorbar;
%moose=caxis;caxis(moose(2)+[-60,0]);
xlabel('f_x, cycles/pixel');ylabel('f_x, cycles/pixel');
xlabel('f_x, cycles/pixel');ylabel('f_x, cycles/pixel');
title('Coherent BP Filter, dB');

fig10a=figure;imagesc(fax,fax,angle(mask2coh)*180/pi);axis image;
colormap('hsv');
colorbar;
xlabel('f_x, cycles/pixel');ylabel('f_x, cycles/pixel');
xlabel('f_x, cycles/pixel');ylabel('f_x, cycles/pixel');
title('Coherent BP Filter Phase, deg');

fig12=figure;imagesc(fax,fax,10*log10(abs(mask2)));axis image;colorbar;
moose=caxis;caxis(moose(2)+[-60,0]);
xlabel('f_x, cycles/pixel');ylabel('f_x, cycles/pixel');
xlabel('f_x, cycles/pixel');ylabel('f_x, cycles/pixel');
title('Incoherent BP Filter, dB');

fig8=figure;imagesc(fax,fax,(10*log10(abs(cbfmask2))));axis image;
moose=caxis;caxis(moose(2)+[-60,0]);
colorbar;
xlabel('f_x, cycles/pixel');ylabel('f_x, cycles/pixel');
title(['Output Spectrum, dB']); 

figure;imagesc(xax,xax,real(cbimage1));axis image;colormap(gray);
title('Low--Pass Filtered');

fig14=figure;imagesc(xax,xax,real(cbimage2));axis image;colormap(gray);
title('Band--Pass Filtered');

psf2=fftshift(ifft2(fftshift(mask2))); % Ifft to get the image
figure;imagesc(xax,xax,abs(psf2));axis image;
colorbar;
title('Incoherent PSF Amplitude');

figure;imagesc(xax,xax,angle(psf2));colormap('hsv');axis image;
colorbar;
title('Incoherent PSF Amplitude');

