%% HORSESHOE plots the horseshoe x,y curve
%
% SYNTAX:
%  horeseshoe;
%
% by Chuck DiMarzio
%    Northeastern University
%    December 2008
[x,y]=meshgrid(0:0.001:1,0:0.001:1);z=1-x-y;
axyz(:,:,1)=x;axyz(:,:,2)=y;axyz(:,:,3)=z;
rgb=xyz2rgb(axyz);

load xyzdata;% a(1) is wavelength, a(2) is xbar, b(2) is ybar, c(2) is
                % zbar 
%  Find the boundary of the xyz plot
denom=(a(:,2)+b(:,2)+c(:,2));
xbound=a(:,2)./denom;
ybound=b(:,2)./denom;

c=rgb/max(max(max(rgb))); 
c(c<0)=0;
csave=c;
c=c./repmat(max(c,[],3),[1,1,3]);

% Generate unmask which is 1 outside the boundary and 0 inside
%  This is done by checking the cross producct of a vector from each
%  boundary point to the next with a vector from that boundary point to
%  a point in the image, and unmasking if negative.
unmask=(zeros(size(x))==1);
nstart=7;nstop=64;
for n=nstart:nstop;
x1=xbound(n);y1=ybound(n);x2=xbound(n+1);y2=ybound(n+1);
cp=(x-x1)*(y2-y1)-(y-y1)*(x2-x1);
test=cp<0;
unmask=unmask|test;
end;
x1=xbound(nstop);y1=ybound(nstop);x2=xbound(nstart);y2=ybound(nstart);
cp=(x-x1)*(y2-y1)-(y-y1)*(x2-x1);
test=cp<0;
unmask=unmask|test;
% Whiten everything that is outside the boundary
for n=1:3;
c(:,:,n)=c(:,:,n).*(1-unmask)+unmask;
end;


figure;imagesc(x(1,:),y(:,1),c);axis xy;axis equal;axis image;
hold on;
plot(xbound,ybound,'k-');
xlabel('x');ylabel('y');
