%% DETECTORS produces miscellaneous plots for detectors
%
% by Chuck DiMarzio
%    Northeastern University
%    June 2009
%
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
%% Read in constants
constant;
%% Generic photon detector spectrum
lambda=(0:10e-9:1.5e-6);

etaq=zeros(size(lambda));  % Quantum efficiency 
cutoff=1.2e-6;
etaq(lambda<cutoff)=1;

%%
%
% $$\rho_i=\frac{e}{h \nu} = \frac{e \lambda}{h c}  $$
%
rhoi=etaq.*lambda*electron/(h*c);  % Current responsivity

fig1=figure;plot(lambda*1e9,rhoi);grid on;
xlabel('\lambda, nm');ylabel('\rho_i, A/W');
text(200,0.55,'\eta = 1.00');

lambda=(0:10e-9:1.5e-6);

%%  Realistic data for silicon
load silicon;  % Load quantum efficiency

rhoi1=etaq.*lambda_silicon*electron/(h*c);  % Current responsivity
rhoi2=etaq_silicon.*rhoi1;  % Actual Current responsivity
fig2=figure;plot(lambda_silicon*1e9,rhoi1,lambda_silicon*1e9,rhoi2);
text(200,.55,'\eta = 1.00');
grid on;
xlabel('\lambda, nm');ylabel('\rho_i, A/W');

%%  Realistic data for pmt
load pmt;  % Load quantum efficiency
rhoi3=etaq.*lambda_silicon*electron/(h*c);  % Current responsivity
rhoi4=etaq_pmt.*rhoi3;  % Actual Current responsivity
%
% Show straight line for 25 percent quantum efficiency
fig3=figure;plot(lambda_pmt*1e9,rhoi3/4,lambda_pmt*1e9,rhoi4);grid on;
text(200,.13,'\eta = 0.25');
xlabel('\lambda, nm');ylabel('\rho_i, A/W');

