%% PCOUNT  Photon counting examples
%   by Chuck DiMarzio
%      Northeastern University
%      June 2009
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
%
%% Poisson Distribution
% $$ P(n) = \frac{e^{ - \bar{n}} \bar{n}^n}{n!} $$
%
%% Low mean number (0.1)
nbar=0.1;n=(0:10);
p=exp(-nbar).*nbar.^n./factorial(n);
fig1=figure;bar(n,p);grid on;
xlabel('n, Number');
ylabel('P(n), Probability');


%% Moderate mean number (1)
nbar=1;n=(0:10);
p=exp(-nbar).*nbar.^n./factorial(n);
fig2=figure;bar(n,p);grid on;

xlabel('n, Number');
ylabel('P(n), Probability');

%% Moderate mean number (3.5)
nbar=3.5;n=(0:10);
p=exp(-nbar).*nbar.^n./factorial(n);
fig3=figure;bar(n,p);grid on;
xlabel('n, Number');
ylabel('P(n), Probability');

%% Moderate mean number (50)
nbar=50;n=(20:80);
p=exp(-nbar).*nbar.^n./factorial(n);
fig4=figure;bar(n,p);grid on;
xlabel('n, Number');
ylabel('P(n), Probability');

%% Probability of 1 or more
n=0;nbar=10.^(-2:.01:1);
p0=exp(-nbar).*nbar.^n./factorial(n); % probability of zero
n=1;p1=exp(-nbar).*nbar.^n./factorial(n); % probability of one
fig5=figure;loglog(nbar,1-p0,nbar,1-p0-p1);grid on;
xlabel('nbar, Mean number');
ylabel('P(n>0,1), Probability');
axis([1e-2,1e1,1e-4,1]);
text(3e-2,1e-2,'P(n>0)');
text(3e-1,1e-2,'P(n>1)');
