%% SNR  Examples of signal and noise.
%
%   by Chuck DiMarzio
%      Northeastern University
%      June 2009
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
%
constant;  % Read in the physical constants
lambda=[500e-9,10.59e-6]; % Two example wavelengths in meters
disp('-----------------------------');
p=1e-6 % Optical Power in Watts
R=1e4; % Transimpedance amplifier feedback resistor, Ohms
B=10e6; % Bandwidth in Hertz
rhoi=electron/h/c*lambda  % Current Responsivity
%
%% Signal data
photonspersecond=p/h/c.*lambda; % Mean photon count per second
display(photonspersecond);
nbar=p/B/h/c.*lambda % Mean photon count in time interval 1/B
current=p.*rhoi  % Mean photo--current
voltage=current*R  % Mean voltage at output of amplifier


%% Noise data
sqrt_nbar=sqrt(nbar) % standard deviation of photon count in 1/B
noisecurrent=sqrt_nbar*B*electron % Noise current
noisevoltage=noisecurrent*R % Noise Voltage
snr_db=10*log10((voltage./noisevoltage).^2);  % SNR in dB
display(snr_db);
%% Repeat for higher power

disp('-----------------------------');
p=1e-12 % Optical Power in Watts
R=1e4; % Transimpedance amplifier feedback resistor, Ohms
B=10e6; % Bandwidth in Hertz
rhoi=electron/h/c*lambda  % Current Responsivity
%
%% Signal data
photonspersecond=p/h/c.*lambda % Mean photon count per second
nbar=p/B/h/c.*lambda % Mean photon count in time interval 1/B
current=p.*rhoi  % Mean photo--current
voltage=current*R  % Mean voltage at output of amplifier


%% Noise data
sqrt_nbar=sqrt(nbar) % standard deviation of photon count in 1/B
noisecurrent=sqrt_nbar*B*electron % Noise current
noisevoltage=noisecurrent*R % Noise Voltage
snr_db=10*log10((voltage./noisevoltage).^2)  % SNR in dB
disp('-----------------------------');
