% lens.m  Various lens equations
% by Chuck DiMarzio
%    Northesastern University
%    December 2008

% Radii of curvature for given focal length
ra=[-25:0.1:25];  % Radius axis
n=1.5; 
fa=[-10,10];     % Focal lengths
[f,r1]=meshgrid(fa,ra);  % r1 is the phorizontal axis
r2=1./(1./r1-1./(f*(n-1)));   % Calculate r2
ax=25; % Axis size
figure;plot(ra,r2(:,1),'--',ra,r2(:,2),'-',...;
   0.7*[ax,-ax],0.7*[-ax,ax],'k-',0.7*[ax,-ax],0.7*[ax,-ax],'k-',...
   [0,0],[-ax,ax],'k-',[-ax,ax],[0,0],'k-');grid on;
axis equal;axis(ax*[-1,1,-1,1]);
xlabel('r_1, Radius of First Surface');
ylabel('r_2, Radius of Second Surface');


hold on;
for r1p=[-0.8,-0.25,0.25,0.8]*ax;  % Show the lens shapes on the plot
  for r2p=[-0.8,-0.25,0.25,0.8]*ax;
[x,y,yedge]=temp(r1p,r2p,5,1);plot(r1p+x*ax/10/yedge,r2p+y*ax/10/yedge);
  end;
end;
hold off;
print('-deps',[epspath,'2-25-bending.eps']);

% Plot using inverse radii
ax=1/4;f1=10;n=1.5;
r1inv=ax*[-1:0.1:1];  %f This is 1/r1
p1=(n-1)*r1inv;
p2=1/f1-p1;
r2inv=-p2/(n-1);
figure;plot(r1inv,r2inv,'k-',...
            [-ax,ax],[-ax,ax],'k:');
hold on;
f1=-10;
p2=1/f1-p1;
r2inv=-p2/(n-1);
plot(r1inv,r2inv,'k--')
axis equal;axis(ax*[-1,1,-1,1]);grid on;

ha=gca;
moose=get(ha,'XTickLabel');
set(ha,'XTickLabel',num2str(1./str2num(moose)));
moose=get(ha,'YTickLabel');
set(ha,'YTickLabel',num2str(1./str2num(moose)));
xlabel('r_1, Radius of First Surface');
ylabel('r_2, Radius of Second Surface');
hold on;

for px1=[-0.8,-0.4,0.001,0.4,0.8]*ax;  % Px is the inverse of r
  for px2=[-0.8,-0.4,0.001,0.4,0.8]*ax;


r1p=1/px1;
r2p=-1/px2;
[x,y,yedge]=temp(r1p,-r2p,5,1);plot(px1+x*ax/10/yedge,px2+y*ax/10/yedge);

  end;
end;
hold off;
print('-deps',[epspath,'2-26-bending.eps']);

%  Object and image distance for positive and negative lenses

ax=60;
sa=[-60:60];   % Object distance
fa=[-10,10];   % Two focal lengths
[f,s]=meshgrid(fa,sa);
sprime=1./(1./f-1./s);  % Image distance
figure;plot(sa,sprime(:,1),'--',sa,sprime(:,2),'-',...
   [0,0],[-ax,ax],'k-',[-ax,ax],[0,0],'k-');grid on;
axis equal;axis(ax*[-1,1,-1,1]);
xlabel('s, Object Distance');
ylabel('s'', Image Distance');
text(ax/3,ax/2,['Real Object,',char(10),'Real Image']);
text(ax/3,-0.8*ax,['Real Object,',char(10),'Virtual Image']);
text(-0.8*ax,ax/2,['Virtual Object,',char(10),'Real Image']);
text(-0.8*ax,-0.8*ax,['Virtual Object,',char(10),'Virtual Image']);
print('-deps',[epspath,'2-27-lenseq.eps']);


% Principal planes vs thickness

ax=5;
f1=10;n=1.5;
z12=[0:0.01:1]*ax;
p1=1/f1/2;
r1inv=-p1/(n-1);
p2=1/f1-p1;
r2inv=-p2/(n-1);
r1=1/r1inv
r2=1/r2inv
p=p1+p2-z12/n*p1*p2;
f=1./p;  % Focal length, for plotting

h=-p2/n./p.*z12;
hprime=-p1/n./p.*z12;

vz=-z12/2;
hz=vz-h;
vzp=z12/2;
hzp=vzp+hprime;
fz=--hz-f;
fzp=hzp+f;
figure;plot(vz,z12,'-',hz,z12,'--',vzp,z12,'-',hzp,z12,'--',...
            fz,z12,'-.',fzp,z12,'-.');
xlabel('Locations');ylabel('z_{12}, Lens Thickness');
grid on;
print('-deps',[epspath,'3-6-ppl.eps']);

% Principal planes vs. bending n=1.5
z12=3;
ax=1/4;f1=10;n=1.5;  % Set up an 1/r1 axis
r1inv=ax*[-1:0.1:1];  %f This is 1/r1
p1=(n-1)*r1inv;
p2=1/f1-p1;
r2inv=-p2/(n-1);
p=p1+p2+z12/n*p1.*p2;
f=1./p;  % Focal length, for plotting

h=-p2/n./p.*z12;
hprime=-p1/n./p.*z12;

vz=-z12/2*ones(size(r1inv));
hz=vz-h;
vzp=z12/2*ones(size(r1inv));
hzp=vzp+hprime;
fz=hz-f;
fzp=hzp+f;
figure;plot(vz,r1inv,'-',hz,r1inv,'--',vzp,r1inv,'-',hzp,r1inv,'--',...
            fz,r1inv,'-.',fzp,r1inv,'-.');
elk=axis;
axis([2*f1*[-1,1],elk(3:4)]);
ha=gca;
moose=get(ha,'YTickLabel');
set(ha,'YTickLabel',num2str(1./str2num(moose),2));
xlabel('Locations');
ylabel('r_1, Radius of Curvature');
grid on;
hold on;

pt1=find(abs(r1inv+r2inv)==min(abs(r1inv+r2inv)));  % Biconvex
r1p=1/r1inv(pt1);
r2p=1/r2inv(pt1);
elk=axis;
xax=elk(2)-elk(1);  % length of x axis
yax=elk(4)-elk(3);  % length of y axis
xplot=elk(1)+xax*0.05;
yb=min(abs([r1p,r2p]))/2;  % semidiameter of the lens: keep for other shapes
[x,y,yedge]=lensshape(r1p,r2p,yb,0.5);
plot(xplot+x*xax/20/yedge,1/r1p+y*yax/20/yedge);
axis(elk);

pt2=find(abs(r1inv)==min(abs(r1inv))); % planoconvex
r1p=1/r1inv(pt2);
r2p=1/r2inv(pt2);
elk=axis;
xax=elk(2)-elk(1);  % length of x axis
yax=elk(4)-elk(3);  % length of y axis
xplot=elk(1)+xax*0.05;
[x,y,yedge]=lensshape(r1p,r2p,yb,0.5);
plot(xplot+x*xax/20/yedge,1/r1p+y*yax/20/yedge);
axis(elk);

pt3=find(abs(r2inv)==min(abs(r2inv))); % convexplano
r1p=1/r1inv(pt3);
r2p=1/r2inv(pt3);
elk=axis;
xax=elk(2)-elk(1);  % length of x axis
yax=elk(4)-elk(3);  % length of y axis
xplot=elk(1)+xax*0.05;
[x,y,yedge]=lensshape(r1p,r2p,yb,0.5);
plot(xplot+x*xax/20/yedge,1/r1p+y*yax/20/yedge);
axis(elk);

for nn=1:3;
pt4=pt3+nn*(pt3-pt1);  % Meniscus
if(pt4>0 & pt4 <length(r1inv));
  r1p=1/r1inv(pt4);
  r2p=1/r2inv(pt4);
  elk=axis;
  xax=elk(2)-elk(1);  % length of x axis
  yax=elk(4)-elk(3);  % length of y axis
  xplot=elk(1)+xax*0.05;
  [x,y,yedge]=lensshape(r1p,r2p,yb,0.5);
  plot(xplot+x*xax/20/yedge,1/r1p+y*yax/20/yedge);
  axis(elk);
end;
end;

for nn=1:3;
pt5=pt2+nn*(pt2-pt1);  % Other Meniscus
if(pt5>0 & pt5 <length(r1inv));
  r1p=1/r1inv(pt5);
  r2p=1/r2inv(pt5);
  elk=axis;
  xax=elk(2)-elk(1);  % length of x axis
  yax=elk(4)-elk(3);  % length of y axis
  xplot=elk(1)+xax*0.05;
  [x,y,yedge]=lensshape(r1p,r2p,yb,0.5);
  plot(xplot+x*xax/20/yedge,1/r1p+y*yax/20/yedge);
  axis(elk);
end;
end;
print('-deps',[epspath,'3-7-ppl.eps']);

% Principal planes vs. bending n=4
z12=2;
ax=1/10;f1=10;n=4;  % Set up an 1/r1 axis
r1inv=ax*[-1:0.1:1];  %f This is 1/r1
p1=(n-1)*r1inv;
p2=1/f1-p1;
r2inv=-p2/(n-1);
p=p1+p2+z12/n*p1.*p2;
f=1./p;  % Focal length, for plotting

h=-p2/n./p.*z12;
hprime=-p1/n./p.*z12;

vz=-z12/2*ones(size(r1inv));
hz=vz-h;
vzp=z12/2*ones(size(r1inv));
hzp=vzp+hprime;
fz=hz-f;
fzp=hzp+f;
figure;plot(vz,r1inv,'-',hz,r1inv,'--',vzp,r1inv,'-',hzp,r1inv,'--',...
            fz,r1inv,'-.',fzp,r1inv,'-.');
elk=axis;
axis([2*f1*[-1,1],elk(3:4)]);
h=gca;
moose=get(h,'YTickLabel');
set(h,'YTickLabel',num2str(1./str2num(moose),2));
xlabel('Locations');
ylabel('r_1, Radius of Curvature');
grid on;
hold on;

pt1=find(abs(r1inv+r2inv)==min(abs(r1inv+r2inv)));  % Biconvex
r1p=1/r1inv(pt1);
r2p=1/r2inv(pt1);
elk=axis;
xax=elk(2)-elk(1);  % length of x axis
yax=elk(4)-elk(3);  % length of y axis
indent=0.2;  %  For positioning the lens marker in x
dindent=0.04;
xplot=elk(1)+xax*indent;  
yb=min(abs([r1p,r2p]))/2;  % semidiameter of the lens: keep for other shapes
[x,y,yedge]=lensshape(r1p,r2p,yb,0.5);
plot(xplot+x*xax/20/yedge,1/r1p+y*yax/20/yedge);
axis(elk);

pt2=find(abs(r1inv)==min(abs(r1inv))); % planoconvex
r1p=1/r1inv(pt2);
r2p=1/r2inv(pt2);
elk=axis;
xax=elk(2)-elk(1);  % length of x axis
yax=elk(4)-elk(3);  % length of y axis
xplot=elk(1)+xax*(indent-dindent);
[x,y,yedge]=lensshape(r1p,r2p,yb,0.5);
plot(xplot+x*xax/20/yedge,1/r1p+y*yax/20/yedge);
axis(elk);

pt3=find(abs(r2inv)==min(abs(r2inv))); % convexplano
r1p=1/r1inv(pt3);
r2p=1/r2inv(pt3);
elk=axis;
xax=elk(2)-elk(1);  % length of x axis
yax=elk(4)-elk(3);  % length of y axis
xplot=elk(1)+xax*(indent-dindent);
[x,y,yedge]=lensshape(r1p,r2p,yb,0.5);
plot(xplot+x*xax/20/yedge,1/r1p+y*yax/20/yedge);
axis(elk);

for nn=1:3;
pt4=pt3+nn*(pt3-pt1);  % Meniscus
if(pt4>0 & pt4 <length(r1inv));
  r1p=1/r1inv(pt4);
  r2p=1/r2inv(pt4);
  elk=axis;
  xax=elk(2)-elk(1);  % length of x axis
  yax=elk(4)-elk(3);  % length of y axis
  xplot=elk(1)+xax*(indent-(nn+1)*dindent);
  [x,y,yedge]=lensshape(r1p,r2p,yb,0.5);
  plot(xplot+x*xax/20/yedge,1/r1p+y*yax/20/yedge);
  axis(elk);
end;
end;

for nn=1:3;
pt5=pt2+nn*(pt2-pt1);  % Other Meniscus
if(pt5>0 & pt5 <length(r1inv));
  r1p=1/r1inv(pt5);
  r2p=1/r2inv(pt5);
  elk=axis;
  xax=elk(2)-elk(1);  % length of x axis
  yax=elk(4)-elk(3);  % length of y axis
  xplot=elk(1)+xax*(indent-(nn+1)*dindent);
  [x,y,yedge]=lensshape(r1p,r2p,yb,0.5);
  plot(xplot+x*xax/20/yedge,1/r1p+y*yax/20/yedge);
  axis(elk);
end;
end;
print('-deps',[epspath,'3-8-ppl.eps']);
