function [x,y,yedge]=temp(rr1,rr2,yedgetarget,thtarget);
%
% [x,y]=lensshape(rr1,rr2,yedge);
% Returns x and y as the coordinates of the outline of a lens with radius
% of curvature r1 on the first surface and r2 on the second, with a
% semi-diameter of yedge, and  thickness, th.  Units can be any length
% unit provided they are  consistent.  Radius of curvature is defined as
% positive for surfaces that  are convex to the left.  The axial thickness
% will be th if that leaves the edge thickness greater than zero.
% Otherwise, th will be the edge thickness
%
% by Chuck DiMarzio
%    Northeastern University
%    December 2008
%
%
yedge=min([abs(rr1)*0.7,abs(rr2)*0.7,yedgetarget]);
yy=yedge*[-1:0.1:1];
if(abs(rr1)==Inf);
  xedge1=-thtarget/2;
else;
  xedge1=-thtarget/2+rr1.*(1-sqrt(1-yedge^2/rr1.^2));
end;
if(abs(rr2)==Inf);
  xedge2=thtarget/2;
else;
  xedge2=thtarget/2+rr2.*(1-sqrt(1-yedge.^2/rr2.^2));
end;
xtest=xedge2-xedge1;  % Check for negative edge
if (xtest>0); 
  th=thtarget;
else;
  th=thtarget-xtest;  % xtest is negative... increase the thickness
end; 
if(abs(rr1)==Inf);
  x1=-th/2*ones(size(yy));
else;
  x1=-th/2+rr1.*(1-sqrt(1-yy.^2/rr1.^2));
end;
if(abs(rr2)==Inf);
  x2=th/2*ones(size(yy));
else;
  x2=th/2+rr2.*(1-sqrt(1-yy.^2/rr2.^2));
end;
x=[x1,fliplr(x2),x1(1)];
y=[yy,fliplr(yy),yy(1)];
