%% chromatic.m shows an example of chromatic aberrations
%
% requires CODDINGTON
%
% See Also:
%  COMA, ASTIG, ABDEMO
%
% by Chuck DiMarzio
%    Northeastern University
%    2011
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
% Index data from 
% http://refractiveindex.info/
% 
C1 = 1.03961212;
C2 = 0.00600069867;
C3 = 0.231792344;
C4 = 0.0200179144;
C5 = 1.01046945;
C6 = 103.560653;
lambda=(0.3:0.01:2.5); % lambda in microns for the equation
n2m1 = C1*lambda.^2./(lambda.^2-C2) +...
       C3*lambda.^2./(lambda.^2-C4) + ...
       C5*lambda.^2./(lambda.^2-C6);
n=sqrt(n2m1+1);
fig1=figure;plot(lambda*1000,n);grid on;
xlabel('\lambda, Wavelength, nm.');
ylabel('n, Index of Refraction');
%
%
%% Set nominal focal length.
% $$\frac{1}{f} = (n-1)(\frac{1}{r_1}-\frac{1}{r_2})$$
%
%  The lensmakers equation for a thin lens is 
% Let's optimize for spherical aberration assuming object at infinity
%
% $$p = f \frac{s'-s}{s'+s}$$, \ \ 
% $$s \rightarrow \infty $$
%
lambdanom=0.500;
nnom=1.52141;
fnom=4000; % Keep everything in microns now.  This could be a 40x microscope
           % objective with a 160-mm tube length.
p=-1
q=2*(nnom^2-1)*p/(nnom+2)
[ls,qmin]=coddington(p,[],fnom,1,nnom);
%% compute radii using 
% $$q=\frac{r_2-r_1}{r_2+r_1}$$ 
% and 
% $$\frac{1}{f} = (n-1)(\frac{1}{r_1}-\frac{1}{r_2}) $$
r1=2*fnom*q/(q+1)*(nnom-1);
r2=-2*fnom*q/(q-1)*(nnom-1);
%
%
%% Find actual focal length vs. wavelength.
% $$\frac{1}{f} = (n-1)(\frac{1}{r_1}-\frac{1}{r_2}) $$
fchrom=1./((n-1)*(1/r1-1/r2));
fig2=figure;plot(lambda*1000,fchrom/1000);grid on;
xlabel('\lambda, Wavelength, nm.');
ylabel('f, Focal Length, mm');
moose=axis;
%%
%  Chromatic aberration is severe, causing focal shifts of close to 100
%  micrometers over the visible spectrum.


%% Compare focal change caused by spherical aberration. 
% Remember...
%%
% $$ ls = \frac{1}{s'} - \frac{1}{s'(0)} $$
%
h=(10:10:600);
na=sin(atan(h/fnom));  % Plot vs. NA
[ls,qmin]=coddington(p,q,fnom,h,nnom);
fspher=1./(ls+1/fnom);
fig3=figure;plot(na,fspher/1000);grid on;
xlabel('NA');
ylabel('f_h, Focal Length, mm');
axis([0,0.2,moose([3,4])]);
%%
%
% Spherical aberration is worse than chromatic, even for these very small
% numerical apertures.
