%% coma.m demonstrates coma
%
%  See Also:  ABDEMO, ASTIG, CHROMATIC, DISTORTION, SPHERICAL
%
% by Chuck DiMarzio
%    Northeastern University
%    2011
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
% Generate pupil space in polar coordinates in rho phi
philist=(0:360)*pi/180; % radians
rholist=(0.2:0.2:1);
%
%% Set up parameters for the problem
zobject=-10;
xobject=1;
p0=[xobject,0,zobject]'; % object location on the z axis
r=2; % radius of sphere
pc=[0,0,r]'; % sphere center
n=1.5; % index of refraction of glass
zimage=n/((n-1)/r-1/(-zobject));
endplane=zimage;  % end plane for displaying rays at paraxial focus
%
zplot=[];xplot=[]; % arrays for plot variables
%
hmax=1;  % Maximum height of ray above lens vertex

%% Trace rays exactly
phiplot=zeros(1,length(rholist)*length(philist));
rhoplot=zeros(1,length(rholist)*length(philist));
xshot=zeros(1,length(rholist)*length(philist));
yshot=zeros(1,length(rholist)*length(philist));
count=0;
for rho=rholist; % Loop on rays: h is height above vertex
  for phi=philist;
    count=count+1;
    pt=[rho*cos(phi),rho*sin(phi),0]'; % point in vertex plane
    v=pt-p0; % vector from object to lens
    v=v/sqrt(v'*v); % normalize it
    [s1,s2]=raysphere(p0,pc,v,r);
    p1=p0+s1*v;
    nor=-(p1-pc)/sqrt((p1-pc)'*(p1-pc)); % Unit normal
    vnew=v/n+(sqrt(1-(1/n)^2*(1-(v'*nor)^2))-v'*nor/n)*nor;
    p2=p1+vnew/vnew(3)*(zimage-p1(3));
    p3=p1+vnew/vnew(3)*(endplane-p1(3));
    zplot=[zplot;p0(3),p1(3),p2(3),p3(3)]; % Don't pre-allocate space.
    yplot=[xplot;p0(2),p1(2),p2(2),p3(2)]; % These variables can have
    xplot=[xplot;p0(1),p1(1),p2(1),p3(1)]; % different sizes.
    phiplot(count)=phi;
    rhoplot(count)=rho;
    xshot(count)=p3(1);
    yshot(count)=p3(2);
  end;
end;

%% Plot 
fig1=figure;plot(yshot,xshot);
axis image;
