%  fresdemo.m
%
%  Computes Fresnel reflection coefficients for a number of situations. 
%  Chuck DiMarzio, Northeastern University, 2008

nlist=[1:.1:4];
brewster=atan(nlist)*180/pi;
brewsteri=atan(1./nlist)*180/pi;
critical=asin(1./nlist)*180/pi;
moose=[1:10:length(nlist)];
fig4=figure;
plot(nlist(moose),brewster(moose),'bx',...
     nlist(moose),brewsteri(moose),'g+',...
     nlist(moose),critical(moose),'ro',...
     nlist,brewster,'b-',...
     nlist,brewsteri,'g-',...
     nlist,critical,'r-');
xlabel('n, Index of Refraction');
ylabel('Angle, Degrees');
legend('Brewster, Air-Medium',...
       'Brewster, Medium-Air',...
       'Critical,Medium-Air','Location','North');

thetad=[0:.1:90];
n=1.5;
[ras,rap,tas,tap]=fresnel(thetad,n);
moose=[1:200:length(thetad)];
fig2=figure;
plot(thetad(moose),ras(moose),'bx',...
     thetad(moose),tas(moose),'g+',...
     thetad(moose),rap(moose),'ro',...
     thetad(moose),tap(moose),'cv',...
     thetad,ras,'b-',...
     thetad,tas,'g-',...
     thetad,rap,'r-',...
     thetad,tap,'c-',...
     [0,100],[0,0],'k');
xlabel('\theta, Angle, deg.');
ylabel('\tau or \rho');
title('Air to Glass')
legend('\rho_s','\tau_s','\rho_p','\tau_p');

n=1.33;
[ras,rap,tas,tap]=fresnel(thetad,n);
RIS=abs(ras).^2;
RIP=abs(rap).^2;
RS=10*log10(RIS);
TS=10*log10(1-RIS);
RP=10*log10(RIP);
TP=10*log10(1-RIP);
moose=[1:200:length(thetad)];
figure;
plot(thetad(moose),RS(moose),'bx',...
     thetad(moose),TS(moose),'g+',...
     thetad(moose),RP(moose),'ro',...
     thetad(moose),TP(moose),'cv',...
     thetad,RS,'b-',...
     thetad,TS,'g-',...
     thetad,RP,'r-',...
     thetad,TP,'c-');
axis([0,90,-20,0]);
xlabel('\theta, Angle, deg.');
ylabel('T or R');
title('Air to Water')
legend('R_s','T_s','R_p','T_p','Location','NorthWest');
print('-depsc',[epspath,'6-7-airwater.eps']);

n=1.5;
[ras,rap,tas,tap]=fresnel(thetad,n);
RIS=abs(ras).^2;
RIP=abs(rap).^2;
RS=10*log10(RIS);
TS=10*log10(1-RIS);
RP=10*log10(RIP);
TP=10*log10(1-RIP);
moose=[1:200:length(thetad)];
figure;
plot(thetad(moose),RS(moose),'bx',...
     thetad(moose),TS(moose),'g+',...
     thetad(moose),RP(moose),'ro',...
     thetad(moose),TP(moose),'cv',...
     thetad,RS,'b-',...
     thetad,TS,'g-',...
     thetad,RP,'r-',...
     thetad,TP,'c-');
axis([0,90,-20,0]);
xlabel('\theta, Angle, deg.');
ylabel('T or R');
title('Air to Glass')
legend('R_s','T_s','R_p','T_p','Location','NorthWest');
print('-depsc',[epspath,'6-8-airglass.eps']);

n=4;
[ras,rap,tas,tap]=fresnel(thetad,n);
RIS=abs(ras).^2;
RIP=abs(rap).^2;
RS=10*log10(RIS);
TS=10*log10(1-RIS);
RP=10*log10(RIP);
TP=10*log10(1-RIP);
moose=[1:200:length(thetad)];
figure;
plot(thetad(moose),RS(moose),'bx',...
     thetad(moose),TS(moose),'g+',...
     thetad(moose),RP(moose),'ro',...
     thetad(moose),TP(moose),'cv',...
     thetad,RS,'b-',...
     thetad,TS,'g-',...
     thetad,RP,'r-',...
     thetad,TP,'c-');
axis([0,90,-20,0]);
xlabel('\theta, Angle, deg.');
ylabel('T or R');
title('Air to Germanium')
legend('R_s','T_s','R_p','T_p','Location','SouthWest');
print('-depsc',[epspath,'6-9-airge.eps']);

n=1/1.5;
[ras,rap,tas,tap]=fresnel(thetad,n);
RIS=abs(ras).^2;
RIP=abs(rap).^2;
RS=10*log10(RIS);
TS=10*log10(1-RIS);
RP=10*log10(RIP);
TP=10*log10(1-RIP);
moose=[1:200:length(thetad)];
figure;
plot(thetad(moose),RS(moose),'bx',...
     thetad(moose),TS(moose),'g+',...
     thetad(moose),RP(moose),'ro',...
     thetad(moose),TP(moose),'cv',...
     thetad,RS,'b-',...
     thetad,TS,'g-',...
     thetad,RP,'r-',...
     thetad,TP,'c-');
axis([0,90,-20,0]);
xlabel('\theta, Angle, deg.');
ylabel('T or R');
title('Glass to Air')
legend('R_s','T_s','R_p','T_p','Location','SouthEast');
print('-depsc',[epspath,'6-10-glassair.eps']);

prs=angle(ras)*180/pi;
pts=angle(tas)*180/pi;
prp=angle(rap)*180/pi;
ptp=angle(tap)*180/pi;
figure;
plot(thetad(moose),prs(moose),'bx',...
     thetad(moose),pts(moose),'g+',...
     thetad(moose),prp(moose),'ro',...
     thetad(moose),ptp(moose),'cv',...
     thetad,prs,'b-',...
     thetad,pts,'g-',...
     thetad,prp,'r-',...
     thetad,ptp,'c-');
axis([0,90,-180,0]);
xlabel('\theta, Angle, deg.');
ylabel('\phi, Phase, deg');
title('Glass to Air')
legend('R_s','T_s','R_p','T_p','Location','SouthWest');
print('-depsc',[epspath,'6-11-glassairp.eps']);

dphase=angle(ras./rap)*180/pi;
figure;
plot(thetad,dphase,'b-');
axis([0,90,0,60]);
xlabel('\theta, Angle, deg.');
ylabel('\phi_{rs}-\phi_{rp}, Phase, deg.');
title('Glass to Air')
print('-depsc',[epspath,'6-12-glassairdif.eps']);

n=4+3*i;
[ras,rap,tas,tap]=fresnel(thetad,n);
RIS=abs(ras).^2;
RIP=abs(rap).^2;
moose=[1:200:length(thetad)];
figure;
plot(thetad(moose),RIS(moose),'bx',...
     thetad(moose),RIP(moose),'ro',...
     thetad,RIS,'b-',...
     thetad,RIP,'r--')
xlabel('\theta, Angle, deg.');
ylabel('T or R');
title('Air to Metal')
legend('R_s','R_p','Location','SouthWest');
print('-depsc',[epspath,'6-13-airmetal.eps']);

prs=unwrap(angle(ras))*180/pi+360;
prp=unwrap(angle(rap))*180/pi;
figure;
plot(thetad(moose),prs(moose),'bx',...
     thetad(moose),prp(moose),'ro',...
     thetad,prs,'b-',...
     thetad,prp,'r--',...
     [0,100],[180,180],'k-')
xlabel('\theta, Angle, deg.');
ylabel('\phi, Phase, deg');
title('Air to Metal')
legend('R_s','R_p','Location','SouthEast');
print('-depsc',[epspath,'6-14-airmetalp.eps']);
