% poldemo.m
%
%  Demonstration of an imperfect polarizer
%  Chuck DiMarzio, Northeastern University, October 2008
%
nfont=2;bookfont;
echo on
inputpower=5e-3; % Watts
insertionloss=0.08;
extinctionratio=10000;
taux=sqrt(1-insertionloss)
tauy=taux/sqrt(extinctionratio)
thetad=[0:.1:90];  % degrees
theta=thetad*pi/180;
transmission=(taux*cos(theta)).^2+(tauy*sin(theta)).^2;
angleout=atan2(tauy*sin(theta),taux*cos(theta));
outputpower=inputpower*transmission;
malus=inputpower*(cos(theta)).^2;  %  Test against Malus Law
echo off
fig1=figure(1);plot(thetad,outputpower*1e3,'b-',thetad,malus*1e3,'r--');
xlabel('\theta_{in}, Polarization Angle, Deg');
ylabel('P_{out}, Output Power, mW');
legend('Output','Malus Law','Location','SouthWest');
display(['Plotting Power in Figure ',num2str(fig1)]);

test=(thetad>87);
fig2=figure(2);
plot(thetad(test),(outputpower(test)*1e6),'b-',...
     thetad(test),(malus(test)*1e6),'r--');
xlabel('\theta_{in}, Polarization Angle, Deg');
ylabel('P_{out}, Output Power, \mu W');
legend('Output','Malus Law','Location','SouthWest');
display(['Plotting Power in Figure ',num2str(fig2)]);

fig3=figure;plot(thetad,angleout*180/pi);
xlabel('\theta_{in}, Polarization Angle, Deg');
ylabel('\theta_{out}, Polarization Angle, Deg');
display(['Plotting Angle in Figure ',num2str(fig3)]);
