%% POLDEMO Demonstrates polarization examples 
%
%  Demonstration of an imperfect polarizer
%  by Chuck DiMarzio
%     Northeastern University
%     October 2008
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
% (See Chapter 6 for variable names)
%
echo on
inputpower=5e-3; % Watts
insertionloss=0.08;
extinctionratio=10000;
taux=sqrt(1-insertionloss) % tau values are for fields 
tauy=taux/sqrt(extinctionratio)
thetad=(0:.1:90);  % degrees
theta=thetad*pi/180;
transmission=(taux*cos(theta)).^2+(tauy*sin(theta)).^2; % Power
angleout=atan2(tauy*sin(theta),taux*cos(theta));
outputpower=inputpower*transmission;
malus=inputpower*(cos(theta)).^2;  %  Test against Malus Law
echo off
fig1=figure;plot(thetad,outputpower*1e3,'-',thetad,malus*1e3,'--');
grid on;
xlabel('\theta_{in}, Polarization Angle, Deg');
ylabel('P_{out}, Output Power, mW');
legend('Output','Malus Law','Location','SouthWest');

test=(thetad>87); % Don't plot too close to 90 degrees
fig2=figure;
plot(thetad(test),(outputpower(test)*1e6),'-',...
     thetad(test),(malus(test)*1e6),'--');
xlabel('\theta_{in}, Polarization Angle, Deg');
ylabel('P_{out}, Output Power, \mu W');
legend('Output','Malus Law','Location','SouthWest');


fig3=figure;plot(thetad,angleout*180/pi);
xlabel('\theta_{in}, Polarization Angle, Deg');
ylabel('\theta_{out}, Polarization Angle, Deg');
