%% RESOLUTION  Figures for section on resolution showing Rayleigh criterion
%
% Requires: FFTAXIS, FFTAXISSHIFT
%
%
% by Chuck DiMarzio
%    Northeastern University
%    2010
%
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
%% Start
xaxis=fftaxisshift((0:1023)*16/1024);
subregion=(floor(length(xaxis)/4):floor(length(xaxis)*3/4));
[x,y]=meshgrid(xaxis,xaxis);
r1=sqrt((x-1e-6).^2+y.^2);  % Move x just a bit to avoid r=1
air1=4*(besselj(1,r1*pi)./(r1*pi)).^2;
r2=sqrt((x-1.22-1e-6).^2+y.^2);
air2=4*(besselj(1,r2*pi)./(r2*pi)).^2;
%
%% Make a color one
c=ones(size(x,1),size(x,2),3);
c(:,:,1)=2./(1+air2)-1;
c(:,:,2)=max(0,2./(1+air1+air2)-1);
c(:,:,3)=2./(1+air1)-1;
gamma=2;
cg=c.^gamma;
fig35c=figure;image(xaxis(subregion),xaxis(subregion),cg(subregion,subregion,:));
axis image;
text(xaxis(subregion(10)),...
     xaxis(subregion(end-10)),['\gamma = ',num2str(gamma)]);
% Black and white for the book
bw=air1+air2;
fig35=figure;
imagesc(xaxis(subregion),xaxis(subregion),bw(subregion,subregion,:));
colormap(flipud(gray));
axis image;
%print('-depsc',[epspath,'8-35-res.eps']);

fig36=figure;plot(xaxis,air1(512,:)+air2(512,:));
xlabel('x D/\lambda, Position');
ylabel('Relative Irradiance');

sinc1=(sinc(x).*sinc(y)).^2;
sinc2=(sinc((x-1)).*sinc(y)).^2;
% Color plot
c=ones(size(x,1),size(x,2),3);
c(:,:,1)=2./(1+sinc2)-1;
c(:,:,2)=max(0,2./(1+sinc1+sinc2)-1);
c(:,:,3)=2./(1+sinc1)-1;
gamma=2;
cg=c.^gamma;
fig37c=figure;image(xaxis(subregion),xaxis(subregion),cg(subregion,subregion,:));
axis image;
text(xaxis(subregion(10)),...
     xaxis(subregion(end-10)),['\gamma = ',num2str(gamma)]);
% Black and white for the book
bw=sinc1+sinc2;
fig37=figure;
imagesc(xaxis(subregion),xaxis(subregion),bw(subregion,subregion,:));
colormap(flipud(gray));
axis image;

fig38=figure;plot(xaxis,sinc1(512,:)+sinc2(512,:));
xlabel('x D/\lambda, Position');
ylabel('Relative Irradiance');


