%% COLLINSB   Collins Chart with track from another file
%
% Internal for COLLINS1 and COLLINS2
%
%             by Chuck DiMarzio
%                Northeastern University
%                November 2008
%
%   needs zlim and blim to be assigned.  Maxima for plot limits
% 
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
%% Start
zstep=0.2;bstep=0.2;zmin=0.2;zmax=6;bmin=0.2;bmax=6;
z=(-zlim:0.2:zlim);
b=(0:0.2:blim);
%
% u = 1/rho, v=-1/b; z + j b = (u + j v)/(u^2 + v^2)
% 
bprime=(bmin:bstep:bmax); 
rhoinv=(-60:0.02:60);  
[u,v]=meshgrid(rhoinv,1./bprime);  % curves of constant b
denom=(u.^2+v.^2);
z1=u./denom;
b1=v./denom;

rho=(zmin:zstep:zmax); 
bprimeinv=(0:0.02:60);
[u,v]=meshgrid(1./rho,bprimeinv);  % curves of constant positive rho
denom=(u.^2+v.^2);
z2=u./denom;
b2=v./denom;

rho=-(zmin:zstep:zmax); 
bprimeinv=(0:0.02:60);
[u,v]=meshgrid(1./rho,bprimeinv);  % curves of constant negative rho
denom=(u.^2+v.^2);
z3=u./denom;
b3=v./denom;

plot([z;z],[b(1);b(end)],'k--',...
     [z(1);z(end)],[b;b],'k--',...
     z1',b1','k--',...
     z2,b2,'k--',...
     z3,b3,'k--','LineWidth',1)
axis image;axis([-zlim,zlim,0,blim]);
xlabel('z, Axial Distance');ylabel('b, Confocal Parameter');
hold on;

% Once again for integer values with solid lines

zstep=1;bstep=1;zmin=1;bmin=1;
z=[-zlim:1:zlim];
b=(0:1:blim);
%
% u = 1/rho, v=-1/b; z + j b = (u + j v)/(u^2 + v^2)
% 
bprime=(bmin:bstep:bmax); 
rhoinv=(-60:0.02:60);  
[u,v]=meshgrid(rhoinv,1./bprime);  % curves of constant b
denom=(u.^2+v.^2);
z1=u./denom;
b1=v./denom;

rho=(zmin:zstep:zmax); 
bprimeinv=(0:0.02:60);
[u,v]=meshgrid(1./rho,bprimeinv);  % curves of constant positive rho
denom=(u.^2+v.^2);
z2=u./denom;
b2=v./denom;

rho=-(zmin:zstep:zmax); 
bprimeinv=(0:0.02:60);
[u,v]=meshgrid(1./rho,bprimeinv);  % curves of constant negative rho
denom=(u.^2+v.^2);
z3=u./denom;
b3=v./denom;


plot([z;z],[b(1);b(end)],'k',...
     [z(1);z(end)],[b;b],'k',...
     z1',b1','k',...
     z2,b2,'k',...
     z3,b3,'k','LineWidth',1)


