function hgm=hgm(m,n,x,y,wx,wy)
%% HGM Hermite Gaussian Function Calculator
%
%  SYNTAX:
%     hgm=hgm(m,n,x,y,wx,wy)
%  where m and n  are the x and y Hermite indices
%        x and y  are coordinates (scalar only)
%       wx and wy are the widths in the x and y directions respectively
%
%   hgm is the normalized field of the Hermite Gaussian
%
%  Requires HERMITEP
%
% By Chuck DiMarzio
%    Northeastern University
%    October 2001
%    Modified December 2008
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
%% start
gaussx=exp(-(x/wx).^2);
gaussy=exp(-(y/wy).^2);
hx=hermitep(n,(sqrt(2)*x/wx))/sqrt(2^n*factorial(n)*wx)*(2/pi)^(1/4).*gaussx;
hy=hermitep(m,(sqrt(2)*y/wy))/sqrt(2^m*factorial(m)*wy)*(2/pi)^(1/4).*gaussy;
hgm=(hy.*hx);
