function [m,frac,sremax,lpeak]=bbody(t,lambda1,lambda2)
% BBODY computes black body radiant exitance in a band of wavelength
%
%
% SYNTAX:
%  m=bbody(t,lambda1,lambda2);
%  m is Radiant Exitance in W/m^2
%  of a black body at temp t, kelvin
%  over wavelengths lambda1 to lambda2, microns
%
%  [m,frac,sremax,lpeak]=bbody(t,lambda1,lambda2);
%  frac is the ratio m divided by the radiant exitance from
%       zero to 100 microns
%  sremax is the maximum spectral radiance in the band
%         in W/m^2/micron
%  lpeak is the wavelength at which it occurs in microns
%
%  By Chuck DiMarzio
%  Northeastern University
%  2006
%
% Requires BBSPEC
%
%  See also: BBSPEC, BBDEMO, BBD
%
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
%% Start for chosen wavelengths
dlambda=0.01;  % Generate a list of wavelengths
lambda=(lambda1:dlambda:lambda2);
spec=bbspec(t,lambda); % Compute the spectral radiant exitance M_lamda
m=sum(spec)*dlambda;   % Compute the radiant exitance, M
%
sremax=max(spec);  %  Find the highest value of the spectrum
lpeak=lambda(find(spec==sremax));  % Where is it in wavelength?
% 
%% Run over whole spectrum from dlambda to 100 microns
lambdafull=(dlambda:dlambda:1e2);  
specfull=bbspec(t,lambdafull);  
mfull=sum(specfull)*dlambda;
frac=m/mfull; % What is fraction of total M that is in band?
