function f=fftaxis(t)
%% FFTAXIS generates a frequency axis to use with FFT
% Specifically, given a vector of equally-spaced time values, computes the
%  corresponding frequency values for an fft.
%
% SYNTAX:
% f=fftaxis(t);
%
% where t is the time axis
%  Note that this function only looks at the length and first two elements
%  of t.  It assumes that all elements are equally spaced in time.
%
% f is the frequncy axis
%
% by Chuck DiMarzio
% Northeastern University
% June 2002
%
% EXAMPLE: (elk is a function of time)
% plot(t,elk);
% moose=fft(elk);
% f=fftaxis(t);
% plot(f,real(moose),f,imag(moose));
%
%
% see also FFTAXISSHIFT
%
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
%% Start
df=(t(2)-t(1))*length(t);
f=((1:length(t))-1)/df;
