function fs=fftaxisshift(f)
%% FFTAXISSHIFT shifts the frequency axis to display the negative and
% positive half Nyquist interval. Use with Matlab's FFTSHIFT
%
% SYNTAX:
% fs=fftaxisshift(f);
%
%  where f is a 1-D array of frequencies from 0 to Nyquist frequency
%
% fs is an array from -Nyquist/2 to +Nyquist/2
%
% EXAMPLE:
%
%  >> N=8;t=[0:N-1];x=cos(2*2*pi*t/N);
%  >> X=fft(x);f=fftaxis(t);
%  >> [f',X']
%  ans =
%          0            -0.0000          
%     0.1250            -0.0000          
%     0.2500             4.0000 + 0.0000i
%     0.3750             0.0000          
%     0.5000             0.0000          
%     0.6250             0.0000          
%     0.7500             4.0000 - 0.0000i
%     0.8750            -0.0000          
%  >> [fftaxisshift(f'),fftshift(X')]
%  ans =
%    -0.5000             0.0000          
%    -0.3750             0.0000          
%    -0.2500             4.0000 - 0.0000i
%    -0.1250            -0.0000          
%          0            -0.0000          
%     0.1250            -0.0000          
%     0.2500             4.0000 + 0.0000i
%     0.3750             0.0000          
%
% See Also:  FFTAXIS
%
% by Chuck DiMarzio
% Northeastern University
% June 2002
% 
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
%% Start
df=f(2)-f(1);
fs=fftshift(f);
fs(1:floor(length(f)/2))=fs(1:floor(length(f)/2))-f(length(f))-df;
