function hermitep=hermitep(n,x)
%% HERMITEP calculates hermite polynomials
%
% SYNTAX:
%  hermitep=hermitep(n,x)
%
% where n is the index and x is the normalized position variable
% by Chuck DiMarzio
%    Northeastern University
%    October 2001
%
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
% note that first one is n=0, so index is np1=n+1
%% Start
np1=n+1;
h=ones(size(x));  % Calculate recursively
     hback1=h;
if np1>1;
   h=2*x;
   if np1>2;
      for nn=2:n;
         hback2=hback1;
         hback1=h;
         h=2*x.*hback1-2*(nn-1)*hback2;
      end;
   end;
end;
hermitep=h;

         