%% XYZTEST Tests xyz.m and shows how close it is to tabulated data.
%
% Requires: xyzdata.mat
%
% by Chuck DiMarzio
%    Northeastern University
%    2001
%
%
%  !! This file may be copied, used, or modified for educational and
%  !! research purposes provided that this header information is not
%  !! removed or altered, and provided that the book is cited in 
%  !! publications, as DiMarzio, Charles A., Optics for Engineers, 
%  !! CRC Press, Boca Raton, FL, 2011.
%  !! http://www.crcpress.com
%  !! Other distribution is prohibited without permission.
%
%% Start
w=[300:5:800];
[x,y,z]=xyz(w);
load xyzdata;
figure;
plot(w,x,'-',w,y,'-',w,z,'-',...
   a(:,1)*1000,a(:,2),'.',...
   b(:,1)*1000,b(:,2),'.',...
   c(:,1)*1000,c(:,2),'.');
xlabel('Wavelength, nm.');
ylabel('x,y,z');

%% chromaticity
xc=x./(x+y+z);
yc=y./(x+y+z);
figure;plot(xc(find(y>0)),yc(find(y>0)));
xlabel('x');ylabel('y');

 k = [[0.2535 0       0      ]                 % arbitrary scaling
     [0      -0.4000 0      ]
     [0      0       0.01327]];
SP75 = [[0.7465 1.4000  0.1748]     % Smith and Pokorny (1975) copunctual
                                    % points for dichromats 
        [0.2535 -0.4000 0.0000]
        [0.0000 0.0000  0.8252]];
XYZLMS = k * inv(SP75); 
     
     
lms=XYZLMS*[x;y;z];
     
l=lms(1,:);
m=lms(2,:);
s=lms(3,:);

figure;plot(w,l,w,m,w,s);
xlabel('\lambda, Wavelength, nm');ylabel('L,M,S');

L=(x.*y+y)/3;
M=(y-x.*y)/3;
figure;plot(w,L,w,M,w,z);
xlabel('\lambda, Wavelength, nm');ylabel('(y+xy)/3,(y-xy)/3,z');

figure;plot(x,z./y);
xlabel('\lambda, Wavelength, nm');ylabel('x,z/y');

