function [X,Y,Z]=xyzspec(lambda,spectrum);
%% Computes X, Y, Z color coordinates from spectral data
%  using a trapeziodal integration of interpolated xbar,ybar,zbar data
%
%  usage:
%  [X,Y,Z]=xyzspec(lambda,spectrum);
%
%  lambda is a vector of wavelengths in nanometers
%  spectrum is the spectrum in any units 
%  X,Y,Z are the color coordinates in the (units of spectrum)*nanometers
%
%  compute x,y using x=X/(X+Y+Z) and y=Y/(X+Y+Z)
%
load('xyzdata');
xbar=zeros(size(lambda));
ybar=zeros(size(lambda));
zbar=zeros(size(lambda));
test=find(lambda>1000*a(1,1)&lambda<1000*a(end,1));
xbar(test)=linterp(1000*a(:,1),a(:,2),lambda(test));
ybar(test)=linterp(1000*b(:,1),b(:,2),lambda(test));
zbar(test)=linterp(1000*c(:,1),c(:,2),lambda(test));
xintegrand=xbar.*spectrum;
yintegrand=ybar.*spectrum;
zintegrand=zbar.*spectrum;
X=trapz(lambda,xintegrand);
Y=trapz(lambda,yintegrand);
Z=trapz(lambda,zintegrand);
